@@ -1,5 +1,4 @@
 
-
 #' Retrieve Nomis datasets
 #'
 #' @description Retrieves specific datasets from Nomis, based on their ID. To
@@ -9,15 +8,15 @@
 #' columns.
 #'
 #' @description To find the code options for a given dataset, use
-#' \code{\link{nomis_get_metadata}} for specific codes, and 
+#' \code{\link{nomis_get_metadata}} for specific codes, and
 #' \code{\link{nomis_codelist}} for code values.
 #'
 #' @description This can be a slow process if querying significant amounts of
 #' data. Guest users are limited to 25,000 rows per query, although
 #' \code{nomisr} identifies queries that will return more than 25,000 rows,
 #' sending individual queries and combining the results of those queries into
-#' a single tibble. In interactive sessions, \code{nomisr} will warn you if 
-#' guest users are requesting more than 350,000 rows of data, and if 
+#' a single tibble. In interactive sessions, \code{nomisr} will warn you if
+#' guest users are requesting more than 350,000 rows of data, and if
 #' registered users are requesting more than 1,500,000 rows.
 #'
 #' @description Note the difference between the \code{time} and \code{date}
@@ -33,10 +32,11 @@
 #'
 #' @param id The ID of the dataset to retrieve.
 #'
-#' @param time Parameter for selecting dates and date ranges. There are two
-#' styles of values that can be used to query time.
+#' @param time Parameter for selecting dates and date ranges. Accepts either a
+#' single date value, or two date values and returns all data between the two
+#' date values, There are two styles of values that can be used to query time.
 #'
-#' The first is one or more of \code{"latest"} (returns the latest available
+#' The first is one or two of \code{"latest"} (returns the latest available
 #' data), \code{"previous"} (the date prior to \code{"latest"}),
 #' \code{"prevyear"} (the date one year prior to \code{"latest"}) or
 #' \code{"first"} (the oldest available data for the dataset).
@@ -51,8 +51,13 @@
 #'
 #' Defaults to \code{NULL}.
 #'
-#' @param date Parameter for selecting specific dates. There are two styles
-#' of values that can be used to query time.
+#' @param date Parameter for selecting specific dates. Accepts one or more date
+#' values. If given multiple values, only data for the given dates will be
+#' returned, but there is no limit to the number of data values. For example,
+#' \code{date=c("latest, latestMINUS3, latestMINUS6")} will return the latest
+#' data, data from three months prior to the latest data and six months prior
+#' to the latest data. There are two styles of values that can be used to 
+#' query time.
 #'
 #' The first is one or more of \code{"latest"} (returns the latest available
 #' data), \code{"previous"} (the date prior to \code{"latest"}),
@@ -80,9 +85,9 @@
 #' If \code{NULL}, returns data for all available statistical measures subject
 #' to other parameters. Defaults to \code{NULL}.
 #'
-#' @param sex The code for sexes/genders to include in the dataset. 
-#' Accepts a string or number, or a vector of strings or numbers. 
-#' \code{nomisr} automatically voids any queries for sex if it is not an 
+#' @param sex The code for sexes/genders to include in the dataset.
+#' Accepts a string or number, or a vector of strings or numbers.
+#' \code{nomisr} automatically voids any queries for sex if it is not an
 #' available code in the requested dataset.
 #'
 #' There are two different codings used for sex, depending on the dataset. For
@@ -91,13 +96,13 @@
 #' Defaults to \code{NULL}, equivalent to \code{c(5,6,7)} for datasets where
 #' sex is an option. For datasets using \code{"C_SEX"}, \code{0} will return
 #' results for males and females, \code{1} only males and
-#' \code{2} only females. Some datasets use \code{"GENDER"} with the same 
-#' values as \code{"SEX"}, which works with both \code{sex} and 
+#' \code{2} only females. Some datasets use \code{"GENDER"} with the same
+#' values as \code{"SEX"}, which works with both \code{sex = <code>} and
 #' \code{gender = <code>} as a dot parameter.
 #'
 #' @param additional_queries Any other additional queries to pass to the API.
 #' See \url{https://www.nomisweb.co.uk/api/v01/help} for instructions on
-#' query structure. Defaults to \code{NULL}. Deprecated in package 
+#' query structure. Defaults to \code{NULL}. Deprecated in package
 #' versions greater than 0.2.0 and will eventually be removed in a
 #' future version.
 #'
@@ -106,15 +111,25 @@
 #'
 #' @param select A character vector of one or more variables to select,
 #' excluding all others. \code{select} is not case sensitive.
-#' 
-#' @param ... Use to pass any other parameters to the API. Useful for passing 
+#'
+#' @param tidy Logical parameter. If \code{TRUE}, converts variable names to
+#' \code{snake_case}, or another style as specified by the
+#' \code{tidy_style} parameter. Defaults to \code{FALSE}.
+#'
+#' @param tidy_style The style to convert variable names to, if
+#' \code{tidy = TRUE}. Accepts one of \code{"snake_case"}, \code{"camelCase"}
+#' and \code{"period.case"}. Defaults to \code{"snake_case"}.
+#'
+#' @param ... Use to pass any other parameters to the API. Useful for passing
 #' concepts that are not available through the default parameters. Only accepts
-#' concepts identified in \code{\link{nomis_get_metadata}} and concept values 
+#' concepts identified in \code{\link{nomis_get_metadata}} and concept values
 #' identified in \code{\link{nomis_codelist}}. Parameters can be quoted or
-#' unquoted, and are not case sensitive. Each parameter should have a name and
-#' a value. For example \code{cause_of_death = 10300} and 
-#' \code{CAUSE_OF_DEATH = 10300} will return the same result when querying 
-#' dataset "NM_161_1".
+#' unquoted. Each parameter should have a name and a value. For example,
+#' \code{CAUSE_OF_DEATH = 10300} when querying dataset \code{"NM_161_1"}.
+#' Parameters are not case sensitive. Note that R using partial matching for
+#' function variables, and so passing a parameter with the same opening
+#' characters as one of the above-named parameters can cause an error unless
+#' the value of the named parameter is specified. See example below:
 #'
 #' @return A tibble containing the selected dataset.
 #' By default, all tibble columns are parsed as characters.
@@ -146,26 +161,38 @@
 #'                                     "C_OCCPUK11H_0_NAME", "obs_vAlUE"))
 #'
 #' tibble::glimpse(emp_by_occupation)
-#' 
+#'
 #' # Deaths in 2016 and 2015 by three specified causes, g
-#' death <- nomis_get_data("NM_161_1", date = c("2016","2015"), 
-#'                         geography = "TYPE480", 
+#' death <- nomis_get_data("NM_161_1", date = c("2016","2015"),
+#'                         geography = "TYPE480",
 #'                         cause_of_death=c(10300, 102088, 270))
-#'                     
+#'
 #' tibble::glimpse(death)
-#' 
-#' 
+#'
+#'
 #' # All causes of death in London in 2016
-#' london_death <- nomis_get_data("NM_1_1", date = c("2016"), 
-#'                                geography = "2013265927", sex = 1, age = 0)              
+#' london_death <- nomis_get_data("NM_1_1", date = c("2016"),
+#'                                geography = "2013265927", sex = 1, age = 0)
 #'
 #' tibble::glimpse(london_death)
 #' }
+#' \dontrun{
+#'  ## Results in an error because `measure` is mistaken for `measures`
+#'  mort_data1 <- nomis_get_data(id = "NM_161_1", date = "2016",
+#'    geography = "TYPE464", sex = 0, cause_of_death = "10381",
+#'    age = 0, measure = 6)
+#'
+#'  ## Does not error because `measures` is specified
+#'  mort_data2 <- nomis_get_data(id = "NM_161_1", date = "2016",
+#'    geography = "TYPE464", sex = 0, measures = NULL,
+#'    cause_of_death = "10381", age = 0, measure = 6)
+#' }
 
 nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
-                           sex = NULL, measures = NULL, 
+                           sex = NULL, measures = NULL,
                            additional_queries = NULL, exclude_missing = FALSE,
-                           select = NULL, ...) {
+                           select = NULL, tidy = FALSE,
+                           tidy_style = "snake_case", ...) {
   if (missing(id)) {
     stop("Dataset ID must be specified", call. = FALSE)
   }
@@ -179,7 +206,7 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
     time_query <- ""
   }
 
-  geography_query <- ifelse(is.null(geography) == FALSE,
+  geography_query <- ifelse(!is.null(geography),
     paste0(
       "&geography=",
       paste0(geography, collapse = ",")
@@ -187,14 +214,6 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
     ""
   )
 
-  measures_query <- ifelse(length(measures) > 0,
-    paste0(
-      "&measures=",
-      paste0(measures, collapse = ",")
-    ),
-    ""
-  )
-
   if (length(additional_queries) > 0) {
     additional_query <- additional_queries
 
@@ -204,7 +223,7 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
     additional_query <- NULL
   }
 
-  # Check for sex queries and return either sex or c_sex
+  # Check for sex queries and return either sex or c_sex or gender
   if (length(sex) > 0) {
     sex_lookup <- nomis_data_info(id)$components.dimension[[1]]$conceptref
 
@@ -212,7 +231,7 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
       sex_query <- paste0("&c_sex=", paste0(sex, collapse = ","))
     } else if ("SEX" %in% sex_lookup) {
       sex_query <- paste0("&sex=", paste0(sex, collapse = ","))
-    }  else if ("GENDER" %in% sex_lookup) {
+    } else if ("GENDER" %in% sex_lookup) {
       sex_query <- paste0("&gender=", paste0(sex, collapse = ","))
     } else {
       sex_query <- ""
@@ -226,7 +245,7 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
     ""
   )
 
-  select_query <- ifelse(length(select) > 0,
+  select_query <- ifelse(!is.null(select),
     paste0(
       "&select=",
       paste0(
@@ -237,21 +256,29 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
     ""
   )
 
+  measures_query <- ifelse(!is.null(measures),
+    paste0(
+      "&MEASURES=",
+      paste0(measures, collapse = ",")
+    ),
+    ""
+  )
+
   dots <- rlang::list2(...) ## eval the dots
+  names(dots) <- toupper(names(dots))
+  dots_vector <- c()
 
-  x <- c()
-  
   for (i in seq_along(dots)) { # retrieve the dots
-    x[i] <- ifelse(length(dots[[i]]) > 0,
+    dots_vector[i] <- ifelse(length(dots[[i]]) > 0,
       paste0(
-        "&", names(dots[i]), "=",
+        "&", toupper(names(dots[i])), "=",
         paste0(dots[[i]], collapse = ",")
       ),
       ""
     )
   }
 
-  dots_query <- paste0(x, collapse = "")
+  dots_query <- paste0(dots_vector, collapse = "")
 
   if (!is.null(getOption("nomisr.API.key"))) {
     api_query <- paste0("&uid=", getOption("nomisr.API.key"))
@@ -262,16 +289,14 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
   }
 
   query <- paste0(
-    id, ".data.csv?", time_query, geography_query, sex_query, measures_query,
-    exclude_query, select_query, api_query, additional_query, dots_query
+    id, ".data.csv?", dots_query, time_query, geography_query, sex_query,
+    exclude_query, select_query, api_query,
+    additional_query, measures_query
   )
 
   first_df <- nomis_get_data_util(query)
 
-  if (nrow(first_df) == 0) {
-    stop("The API request did not return any results.
-         Please check your parameters.", call. = FALSE)
-  }
+  names(first_df) <- toupper(names(first_df))
 
   if (as.numeric(first_df$RECORD_COUNT)[1] >= max_length) {
     # if amount available is over the limit of 15 total calls at a time
@@ -317,9 +342,13 @@ nomis_get_data <- function(id, time = NULL, date = NULL, geography = NULL,
     df <- first_df
   }
 
-  if (length(select) > 0 & !("RECORD_COUNT" %in% select)) {
+  if (!is.null(select) & !("RECORD_COUNT" %in% toupper(select))) {
     df$RECORD_COUNT <- NULL
   }
 
+  if (tidy == TRUE) {
+    df <- nomis_tidy(df, tidy_style)
+  }
+
   df
 }
