@@ -1,7 +1,6 @@
 library(nomisr)
 context("nomis_get_metadata")
 
-
 test_that("nomis_get_metadata return expected format", {
   skip_on_cran()
 
@@ -13,32 +12,27 @@ test_that("nomis_get_metadata return expected format", {
   expect_true(tibble::is_tibble(a))
 
   b <- nomis_get_metadata("NM_1_1", "geography")
-  expect_length(b, 3)
   expect_equal(nrow(b), 7)
   expect_true(tibble::is_tibble(b))
 
   c <- nomis_get_metadata("NM_1_1", "geography", "TYPE")
-  expect_length(c, 2)
   expect_equal(nrow(c), 96)
   expect_true(tibble::is_tibble(c))
 
   d <- nomis_get_metadata(
     id = "NM_893_1", concept = "C_AHTHUK11", type = "1"
   )
-  expect_length(d, 3)
   expect_equal(nrow(d), 1)
   expect_true(tibble::is_tibble(d))
 
   e <- nomis_get_metadata(
     "NM_1_1", "item",
-     geography=1879048226,sex=5
+    geography = 1879048226, sex = 5
   )
-  expect_length(e, 3)
   expect_equal(nrow(e), 5)
   expect_true(tibble::is_tibble(e))
 
   f <- nomis_get_metadata("NM_1_1", "item", search = "*married*")
-  expect_length(f, 3)
   expect_equal(nrow(f), 1)
   expect_true(tibble::is_tibble(f))
 })
